//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : simulation.AlarmBehavior
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  School of Information and Computer Science
//                  University of California at Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   AlarmBehavior is a class that implements the Behavior interface.
// Generally, it "rings" after a certain interval of calling doIts. Its
// doIt method decrements a counter; when it reaches 0 isRinging returns
// true (and the AlarmBehavior is reset for future ringing).
//
//   Note that "no access modifier" for a member means that the member is
// package-friendly: this means that the member is public to all other
// classes in the simulation package, but private elsewhere.
//
// Future Plans   : Javadoc Comments
//
// Program History:
//  10/01/04: R. Pattis - Operational for 15-200
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


package simulation;



public class AlarmBehavior implements Behavior {

  AlarmBehavior (int interval)
  {
    this.interval = interval;
    time = interval;
  }


  public void doIt (Model m)
  {
    time--;
    ringing = (time == 0);
    if (ringing)
      time = interval;
  } 


  boolean isRinging()
  {return ringing;}
  
  
  
  private int time, interval;
  private boolean ringing;
}
