//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : simulation.AnimationPanel
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  School of Information and Computer Science
//                  University of California at Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   This panel displays all the Simulton objects in the model in paint,
// by passing its Graphics context to the model and telling it to display
// all active objects..
//
//   Note that "no access modifier" for a member means that the member is
// package-friendly: this means that the member is public to all other
// classes in the simulation package, but private elsewhere.
//
// Future Plans   : More Comments
//
// Program History:
//  10/20/01: R. Pattis - Operational for 15-100
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


package simulation;


import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.border.BevelBorder;
import javax.swing.BorderFactory;
import javax.swing.JPanel;



class AnimationPanel extends JPanel
{

   //Save model to call its show method in paint
   public AnimationPanel(Model m)
   {
     //Save the model for use in paint
     model = m;
     
     //Create a simple border
     setBorder(BorderFactory.createBevelBorder(BevelBorder.LOWERED));
     
     //Set the prefered size (when the JFrame is packed); it could
     //  be bigger if the button-panel is bigger
     setPreferredSize(new Dimension(300,300));
   }



   //Called by the Controller every 100ms; or, called by the operating
   //  system when a window's contents need to be redrawn (for example,
   //  on resizing, moving a window on/off of this window, etc.)
   //Overriding this method in the JPanel class is the sole reason
   //  for defining the BallPanel class 
   
   public void paint(Graphics g)
   {
    //Always call this class's super paint method first
    super.paint(g);
    
    setBackground(Color.white);
    model.displayAll(g);
   }

 
  
  
   //Instance Variables
   
   private Model model;
}


