//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : simulation.ColoredCircle
//
/// Author         : Richard E. Pattis
//                  Computer Science Department
//                  School of Information and Computer Science
//                  University of California at Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   ColoredCircle is a class for displaying colored circles of arbitray
// colors and size. It also includes some helper methods for computing
// encloses and various bounding boxes, which may be useful in classes
// implementing Simulaton that store references to ColoredCircles for
// their display.
//
// Future Plans   : Javadoc Comments
//
// Program History:
//   10/010/04: R. Pattis - Operational for 15-200
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


package simulation;


import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.Rectangle;



class ColoredCircle implements Displayable {

  ColoredCircle(Color color, int radius)
  {
    this.color  = color;
    this.radius = radius;
  }

  public Dimension getSize()
  {return new Dimension(2*radius,2*radius);}
  

  public void setSize (Dimension newSize)
  {
    if (newSize.height != newSize.width)
      throw new IllegalArgumentException("ColoredCircle:setSize width/height sizes differ:"
                                         +newSize.width+"/"+newSize.height);
    radius = Math.max(0,newSize.width/2);
  }
  

  public void displayAt (Point p, Graphics g)
  {
    g.setColor(color);
    g.fillOval( Math.round(p.x-radius), Math.round(p.y-radius), 2*radius, 2*radius);
  }
  
  
  void setColor (Color newColor)
  {color = newColor;}


  public boolean enclosesAt (Point at, Point p)
  {return at.distanceSq(p.x,p.y) <= radius*radius;}


  public Rectangle getOuterBoxAt(Point p)
  {return new Rectangle(p.x-radius,p.y-radius,2*radius,2*radius);}
  
  
  public Rectangle getInnerBoxAt(Point p)
  {
    int width = (int)(Math.cos(Math.PI/4)*radius); 
    return new Rectangle(p.x-width, p.y-width, 2*width, 2*width);
  }
  
  
  
  //Instance Variables
  private Color color;
  private int   radius;
}



