//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : simulation.Controller
//
/// Author         : Richard E. Pattis
//                  Computer Science Department
//                  School of Information and Computer Science
//                  University of California at Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   The Controller for the Pinball package supplies several buttons
// and also sets a timer to update and show the model regularly, to
// create the animation effect. It also captures mouseclicks and
// keystrokes and sends them to the model.
//
//   Note that "no access modifier" means that the method is package
// friendly: this means the member is public to all other classes in
// the Pinball package, but private elsewhere.
//
// Future Plans   : More Comments
//
// Program History:
//  10/20/01: R. Pattis - Operational for 15-100
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////



package simulation;


import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JButton;
import javax.swing.Timer;



public class Controller
{

  //Trivial constructor (could be automatically supplied by Java)
  public Controller()
  {}


  
  //Refer to the model (for scheduling updateAll) 
  public void addModel(Model m)
  {model = m;}


  
  //Refer to the View (for scheduling repaint) 
  public void addView(View v)
  {view = v;}

  
  
  //Build/Return a Reset button
  JButton getResetButton()
  {
	  JButton b = new JButton();
	  
	  b.addActionListener(new ActionListener() {
		  public void actionPerformed(ActionEvent e)
		  {
		    System.out.println("Debug-Controller: " + "Reset button pressed");
        model.reset();
      }});
	  
	  return b;
  }
    


  //Build/Return an Object button
  JButton getObjectButton(final String kind)
  {
	  JButton b = new JButton();
	  
	  b.addActionListener(new ActionListener() {
		  public void actionPerformed(ActionEvent e)
		  {
		    System.out.println("Debug-Controller: " + "Object button pressed("+kind+")");
        model.nextObject(kind);
      }});
	  
	  return b;
  }
    


  //Build/Return a click controller for the BallPanel
  //The view will attach it to the BallPanel
  MouseAdapter getBallPanelMouseController()
  {
    return
      new MouseAdapter() {
        public void mouseClicked(MouseEvent evt) 
        {
		      System.out.println("Debug-Controller: Mouse clicked ("
		                         +evt.getClickCount()+") at ("+evt.getX()+","
		                         +evt.getY()+")");
          model.mouseClick(evt.getX(),evt.getY(),evt.getClickCount());
        }};
  }



  //Build/Return a key press controller for the BallPanel
  //The view will attach it to the BallPanel
  KeyAdapter getBallPanelKeyController()
  {
    return

      new KeyAdapter() {
				public void keyTyped(KeyEvent evt)
				{
		      System.out.println("Debug-Controller: Key pressed ("
		                         +evt.getKeyChar()+")");
				  //model.keyPressed(evt.getKeyChar());
				}};
	}
  
  

	void animate ()
	{
	  //A bit of magic
	  //Create an action listener, overriding its actionPerformed
	  //  method to update the model and repaint the view
	  //Then, create a timer, so that every 100ms (10 times a second)
	  //  it performs actionPerformced, and start the timer.
	  ActionListener updater = new ActionListener() {
		  public void actionPerformed(ActionEvent e)
			{
				model.updateAll();
				view.repaint();
			}};
			
		Timer tempTimer = new Timer(50, updater);
		tempTimer.start();
  }
    
 
 
   
    
  //Instance Variables
  
  private Model model;
  private View  view;
}


