//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : simulation.Displayable
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  School of Information and Computer Science
//                  University of California at Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   Displayable is an interface shared by all displayable objects.
// See simluation.ColoredCircle and simulation.Icon for two examples.
// It supports the ability to display something at a specified location
// on the screen, get/set the size of the thing being displayed, and
// determine enclosure/bounding-boxes for a specified location on the
// screen.
//
// Future Plans   : Javadoc
//
// Program History:
//   10/010/04: R. Pattis - Operational for 15-200
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////



package simulation;


import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.Rectangle;


public interface Displayable {

  public void      displayAt     (Point p, Graphics g);
  public void      setSize       (Dimension newSize);
  public Dimension getSize       ();
  
  public boolean   enclosesAt    (Point at, Point p);
  public Rectangle getOuterBoxAt (Point p);
  public Rectangle getInnerBoxAt (Point p);

}



