//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : simulation.Icon
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  School of Information and Computer Science
//                  University of California at Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   Icon is a class for displaying an icon (some graphics file). It also
// includes some helper methods for computing encloses and various
// bounding boxes, which are used by the Simulton class for implementing
// approximations to encloses and various bounding boxes. Icons themselves
// are pictures that are rectangular.
//
//   Note that "no access modifier" for a member means that the member is
// package-friendly: this means that the member is public to all other
// classes in the simulation package, but private elsewhere.
//
// Future Plans   : Javadoc
//
// Program History:
//   10/010/04: R. Pattis - Operational for 15-200
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


package simulation;


import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Toolkit;



class Icon implements Displayable {

  Icon (String fileName, int width, int height)
    throws IllegalArgumentException
  {
    Toolkit tk = Toolkit.getDefaultToolkit();
    dimension  = new Dimension(width,height);
    original   = tk.getImage(fileName);
    //if (original == null)
    //  throw new IllegalArgumentException("Icon:Icon fileName not found: "+fileName);
    current    = original.getScaledInstance(dimension.width,dimension.height,Image.SCALE_SMOOTH);
  }


  public Dimension getSize ()
  {return dimension;}
  

  public void setSize (Dimension d)
  {
    dimension = d;
    current   = original.getScaledInstance(dimension.width,dimension.height,Image.SCALE_SMOOTH);
  }
  

  public void displayAt (Point p, Graphics g)
  {g.drawImage(current,p.x-dimension.width/2, p.y-dimension.height/2, null);}
  
  
  public boolean enclosesAt (Point at, Point p)
  {return at.x-dimension.width/2  <= p.x && p.x <= at.x+dimension.width/2 &&
          at.y-dimension.height/2 <= p.y && p.y <= at.y+dimension.height/2;
  }


  public Rectangle getOuterBoxAt(Point p)
  {return new Rectangle(p.x-dimension.width/2,p.y-dimension.height/2,dimension.width,dimension.height);}
  
  
  public Rectangle getInnerBoxAt(Point p)
  {return getOuterBoxAt(p);}


  
  //Instance Variables
  private Dimension dimension;
  private Image     original;
  private Image     current;
}



